{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "nl",
  "action.edit": "Wijzig deze pagina",
  "action.skip": "Ga naar inhoud",
  "clipboard.copy": "Kopiëren naar klembord",
  "clipboard.copied": "Gekopieerd naar klembord",
  "footer.next": "Volgende",
  "footer.previous": "Vorige",
  "meta.comments": "Reacties",
  "meta.source": "Bron",
  "search.config.lang": "nl",
  "search.placeholder": "Zoeken",
  "search.result.placeholder": "Typ om te beginnen met zoeken",
  "search.result.none": "Geen overeenkomende documenten",
  "search.result.one": "1 overeenkomende document",
  "search.result.other": "# overeenkomende documenten",
  "source": "Ga naar repository",
  "source.file.date.created": "Gecreëerd",
  "source.file.date.updated": "Laatst geüpdatet",
  "toc": "Inhoudsopgave"
}[key] }}{% endmacro %}
