{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "pl",
  "action.edit": "Edytuj tę stronę",
  "action.skip": "Przejdź do treści",
  "clipboard.copy": "Kopiuj do schowka",
  "clipboard.copied": "Skopiowane",
  "footer": "Stopka",
  "footer.next": "Następna strona",
  "footer.previous": "Poprzednia strona",
  "header": "Nagłówek",
  "meta.comments": "Komentarze",
  "meta.source": "Kod źródłowy",
  "search.config.pipeline": " ",
  "nav": "Nawigacja",
  "search.placeholder": "Szukaj",
  "search.reset": "Wyczyść",
  "search.result.initializer": "Inicjowanie wyszukiwania",
  "search.result.placeholder": "Zacznij pisać, aby szukać",
  "search.result.none": "Brak wyników wyszukiwania",
  "search.result.one": "Wyniki wyszukiwania: 1",
  "search.result.other": "Wyniki wyszukiwania: #",
  "search.result.more.one": "1 więcej na tej stronie",
  "search.result.more.other": "# więcej na tej stronie",
  "search.result.term.missing": "Brak",
  "source": "Idź do repozytorium",
  "source.file.date.created": "Utworzony",
  "source.file.date.updated": "Ostatnia aktualizacja",
  "tabs": "Zakładki",
  "toc": "Spis treści"
}[key] }}{% endmacro %}
