{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "sl",
  "action.edit": "Uredi stran",
  "action.skip": "Skoči na vsebino",
  "announce.dismiss": "Ne prikaži več",
  "clipboard.copy": "Kopiraj v odložišče",
  "clipboard.copied": "Kopirano v odložišče",
  "consent.accept": "Sprejmi",
  "consent.manage": "Uredi nastavitve",
  "consent.reject": "Zavrni",
  "footer": "Glava",
  "footer.next": "Naslednja stran",
  "footer.previous": "Prejšnja stran",
  "header": "Noga",
  "meta.comments": "Komentarji",
  "meta.source": "Izvorna koda",
  "nav": "Navigacija",
  "search": "Iskanje",
  "search.config.lang": "sl",
  "search.placeholder": "Išči",
  "search.share": "Deli",
  "search.reset": "Počisti",
  "search.result.initializer": "Inicializacija iskanja",
  "search.result.placeholder": "Vpiši iskalni niz",
  "search.result.none": "Ni zadetkov",
  "search.result.one": "1 zadetek",
  "search.result.other": "# zadetkov",
  "search.result.more.one": "Še 1 na tej strani",
  "search.result.more.other": "Še # na tej strani",
  "search.result.term.missing": "Manjka",
  "select.language": "Izberi jezik",
  "select.version": "Izberi različico",
  "source": "Pojdi na repozitorij",
  "source.file.date.created": "Ustvarjeno",
  "source.file.date.updated": "Zadnja posodobitev",
  "tabs": "Zavihki",
  "toc": "Kazalo",
  "top": "Nazaj na vrh"
}[key] }}{% endmacro %}
