{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "es",
  "action.edit": "Editar esta página",
  "action.skip": "Saltar a contenido",
  "clipboard.copy": "Copiar al portapapeles",
  "clipboard.copied": "Copiado al portapapeles",
  "consent.accept": "Aceptar",
  "consent.manage": "Gestionar cookies",
  "footer": "Pie",
  "footer.next": "Siguiente",
  "footer.previous": "Anterior",
  "header": "Cabecera",
  "meta.comments": "Comentarios",
  "meta.source": "Fuente",
  "nav": "Navegación",
  "search.config.lang": "es",
  "search.placeholder": "Búsqueda",
  "search.reset": "Limpiar",
  "search.result.initializer": "Inicializando búsqueda",
  "search.result.placeholder": "Teclee para comenzar búsqueda",
  "search.result.none": "No se encontraron documentos",
  "search.result.one": "1 documento encontrado",
  "search.result.other": "# documentos encontrados",
  "search.result.more.one": "1 más en esta página",
  "search.result.more.other": "# más en esta página",
  "search.result.term.missing": "Falta",
  "select.language": "Seleccionar idioma",
  "select.version": "Seleccionar versión",
  "source": "Ir al repositorio",
  "source.file.date.created": "Creado",
  "source.file.date.updated": "Última actualización",
  "tabs": "Pestañas",
  "toc": "Tabla de contenidos",
  "top": "Volver al principio"
}[key] }}{% endmacro %}
