{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "el",
  "action.edit": "Επεξεργασία αυτής της σελίδας",
  "action.skip": "Μετάβαση στο περιεχόμενο",
  "clipboard.copy": "Αντιγραφή στο πρόχειρο",
  "clipboard.copied": "Αντιγράφηκε στο πρόχειρο",
  "footer": "Υποσέλιδο",
  "footer.next": "Επόμενο",
  "footer.previous": "Προηγούμενο",
  "header": "Κεφαλίδα",
  "meta.comments": "Σχόλια",
  "meta.source": "Πηγή",
  "nav": "Πλοήγηση",
  "search": "Αναζήτηση",
  "search.placeholder": "Αναζήτηση",
  "search.share": "Διαμοίραση",
  "search.reset": "Καθαρισμός",
  "search.result.initializer": "Αρχικοποίηση αναζήτησης",
  "search.result.placeholder": "Πληκτρολογήστε για να αρχίσει η αναζήτηση",
  "search.result.none": "Δεν βρέθηκαν αντίστοιχα αρχεία",
  "search.result.one": "1 έγγραφο ταιριάζει",
  "search.result.other": "# έγγραφα ταιριάζουν",
  "search.result.more.one": "1 ακόμα σε αυτήν τη σελίδα",
  "search.result.more.other": "# ακόμα σε αυτήν τη σελίδα",
  "search.result.term.missing": "Λείπει",
  "select.language": "Επιλογή γλώσσας",
  "select.version": "Επιλογή έκδοσης",
  "source": "Μετάβαση στο αποθετήριο",
  "source.file.date.created": "Δημιουργήθηκε",
  "source.file.date.updated": "τελευταία ενημέρωση",
  "tabs": "Καρτέλες",
  "toc": "Πίνακας περιεχομένων",
  "top": "Επιστροφή στην αρχή"
}[key] }}{% endmacro %}
