{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ur",
  "direction": "rtl",
  "action.edit": "اس صفحے میں ترمیم کریں",
  "action.skip": "براہِ راست مواد پر جائیں",
  "clipboard.copy": "کلِپ بورڈ میں نقل کریں",
  "clipboard.copied": "کلِپ بورڈ میں نقل کر دیا گیا",
  "footer": "ذیلی تحریر",
  "footer.next": "اگلا",
  "footer.previous": "پچھلا",
  "header": "سر تحریر",
  "meta.comments": "تبصرے",
  "meta.source": "ذریعہ",
  "nav": "رہنمائی",
  "search": "تلاش",
  "search.config.pipeline": " ",
  "search.placeholder": "تلاش کریں",
  "search.share": "اشتراک کریں",
  "search.reset": "صاف کریں",
  "search.result.initializer": "تلاش کا آغاز ہو رہا ہے",
  "search.result.placeholder": "تلاش شروع کرنے کے لئے ٹائپ کریں",
  "search.result.none": "کوئی ملتی جلتی دستاویزات نہیں",
  "search.result.one": "۱ ملتی جلتی دستاویز",
  "search.result.other": "# ملتی جلتی دستاویزات",
  "search.result.more.one": "اِس صفحے پر مزید ۱",
  "search.result.more.other": "اِس صفحے پر مزید #",
  "search.result.term.missing": "گمشدہ",
  "select.language": "زبان کا انتخاب کریں",
  "select.version": "ورژن کا انتخاب کریں",
  "source": "ریپازٹری پر جائیں",
  "source.file.date.created": "تخلیق",
  "source.file.date.updated": "آخری بار تجدید",
  "tabs": "ٹیبز",
  "toc": "فہرست",
  "top": "واپس اوپر جائیں"
}[key] }}{% endmacro %}
