{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "gl",
  "action.edit": "Editar esta páxina",
  "action.skip": "Ir ao contido",
  "clipboard.copy": "Copiar no cortapapeis",
  "clipboard.copied": "Copiado no cortapapeis",
  "footer": "Pé",
  "footer.next": "Seguinte",
  "footer.previous": "Anterior",
  "header": "Cabeceira",
  "meta.comments": "Comentarios",
  "meta.source": "Fonte",
  "nav": "Navegación",
  "search.config.lang": "es",
  "search.placeholder": "Procura",
  "search.reset": "Limpar",
  "search.result.initializer": "Inicializando procura",
  "search.result.placeholder": "Insira un termo",
  "search.result.none": "Sen resultados",
  "search.result.one": "1 resultado atopado",
  "search.result.other": "# resultados atopados",
  "search.result.more.one": "1 máis nesta páxina",
  "search.result.more.other": "# máis nesta páxina",
  "search.result.term.missing": "Falta",
  "select.language": "Seleccionar idioma",
  "select.version": "Seleccionar version",
  "source": "Ir ao repositorio",
  "source.file.date.created": "Creada",
  "source.file.date.updated": "Última actualización",
  "tabs": "Pestanas",
  "toc": "Táboa de contidos",
  "top": "Volver ao principio"
}[key] }}{% endmacro %}
