{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "uz",
  "action.edit": "Ushbu sahifani tahrirlash",
  "action.skip": "Tarkibga o'tish",
  "clipboard.copy": "Buferga nusxalash",
  "clipboard.copied": "Buferga nusxalandi",
  "footer": "Pastgi qism",
  "footer.next": "Keyingi sahifa",
  "footer.previous": "Oldingi sahifa",
  "header": "Sarlavha",
  "meta.comments": "Izohlar",
  "meta.source": "Manba",
  "nav": "Navigatsiya",
  "search": "Qidirish",
  "search.config.lang": "tr",
  "search.placeholder": "Qidirish",
  "search.share": "Ulashish",
  "search.reset": "Tozalash",
  "search.result.initializer": "Qidiruv ishga tushirilmoqda",
  "search.result.placeholder": "Qidiruvni boshlash uchun kiriting",
  "search.result.none": "Mos natijalar yo'q",
  "search.result.one": "1 ta mos natija",
  "search.result.other": "# ta mos keladigan natijalar",
  "search.result.more.one": "Ushbu sahifada yana 1 ta natija",
  "search.result.more.other": "Bu sahifada yana # ta natija",
  "search.result.term.missing": "To'ldirilmagan",
  "select.language": "Tilni tanlang",
  "select.version": "Versiyani tanlang",
  "source": "Repozitoriyga o'tish",
  "source.file.date.created": "Yaratildi",
  "source.file.date.updated": "Oxirgi yangilanish",
  "tabs": "Yorliqlar",
  "toc": "Mundarija",
  "top": "Yuqoriga qaytish"
}[key] }}{% endmacro %}
