{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "et",
  "action.edit": "Muuda seda lehte",
  "action.skip": "Keri sisuni",
  "clipboard.copy": "Kopeeri lõikelauale",
  "clipboard.copied": "Kopeeritud",
  "footer.next": "Järgmine",
  "footer.previous": "Eelmine",
  "meta.comments": "Kommentaarid",
  "meta.source": "Lähtekood",
  "search.placeholder": "Otsi",
  "search.result.placeholder": "Otsimiseks kirjuta siia",
  "search.result.none": "Otsingule ei leitud ühtegi vastet",
  "search.result.one": "Leiti üks tulemus",
  "search.result.other": "Leiti # tulemust",
  "source": "Ava repositooriumis",
  "source.file.date.created": "Loodud",
  "source.file.date.updated": "Viimane uuendus",
  "toc": "Sisukord"
}[key] }}{% endmacro %}
