{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "mn",
  "action.edit": "Хуудас засварлах",
  "action.skip": "Агуулгыг алгасах",
  "clipboard.copy": "Хуулах",
  "clipboard.copied": "Санах ойд хуулах",
  "footer": "Хөл",
  "footer.next": "Дараах",
  "footer.previous": "Өмнөх",
  "header": "Толгой",
  "meta.comments": "Сэтгэгдэл",
  "meta.source": "Эх үүсвэр",
  "nav": "Чиглүүлэгч",
  "search.config.lang": "ru",
  "search.placeholder": "Хайлт",
  "search.reset": "Цэвэрлэх",
  "search.result.placeholder": "Хайлтын үгээ бичнэ үү",
  "search.result.none": "Таарц илэрсэнгүй",
  "search.result.one": "1 таарц илэрлээ",
  "search.result.other": "# Тохирох баримт бичиг",
  "search.result.more.one": "1 илүү хуудас байна",
  "search.result.more.other": "# илүү хуудас байна",
  "source": "Хадгалах сан руу очих",
  "source.file.date.created": "Үүсгэсэн",
  "source.file.date.updated": "Сүүлийн шинэчлэлт",
  "tabs": "Табууд",
  "toc": "Агуулга"
}[key] }}{% endmacro %}
