{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ar",
  "direction": "rtl",
  "action.edit": "عدل الصفحة",
  "action.skip": "انتقل إلى المحتوى",
  "clipboard.copy": "نسخ إلى الحافظة",
  "clipboard.copied": "تم النسخ الى الحافظة",
  "footer.next": "التالية",
  "footer.previous": "السابقة",
  "meta.comments": "التعليقات",
  "meta.source": "المصدر",
  "search.config.pipeline": " ",
  "search.placeholder": "بحث",
  "search.result.placeholder": "اكتب لبدء البحث",
  "search.result.none": "لا توجد نتائج",
  "search.result.one": "نتائج البحث مستند واحد",
  "search.result.other": "نتائج البحث # مستندات",
  "source": "اذهب إلى المصدر",
  "source.file.date.created": "خلقت",
  "source.file.date.updated": "اخر تحديث",
  "toc": "جدول المحتويات"
}[key] }}{% endmacro %}
