{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "en",
  "direction": "ltr",
  "action.edit": "Edit this page",
  "action.skip": "Skip to content",
  "action.view": "View source of this page",
  "announce.dismiss": "Don't show this again",
  "clipboard.copy": "Copy to clipboard",
  "clipboard.copied": "Copied to clipboard",
  "consent.accept": "Accept",
  "consent.manage": "Manage settings",
  "consent.reject": "Reject",
  "footer": "Footer",
  "footer.next": "Next",
  "footer.previous": "Previous",
  "header": "Header",
  "meta.comments": "Comments",
  "meta.source": "Source",
  "nav": "Navigation",
  "search": "Search",
  "search.config.lang": "en",
  "search.config.pipeline": "stopWordFilter",
  "search.config.separator": "[\\s\\-]+",
  "search.placeholder": "Search",
  "search.share": "Share",
  "search.reset": "Clear",
  "search.result.initializer": "Initializing search",
  "search.result.placeholder": "Type to start searching",
  "search.result.none": "No matching documents",
  "search.result.one": "1 matching document",
  "search.result.other": "# matching documents",
  "search.result.more.one": "1 more on this page",
  "search.result.more.other": "# more on this page",
  "search.result.term.missing": "Missing",
  "select.language": "Select language",
  "select.version": "Select version",
  "source": "Go to repository",
  "source.file.date.created": "Created",
  "source.file.date.updated": "Last update",
  "tabs": "Tabs",
  "toc": "Table of contents",
  "top": "Back to top"
}[key] }}{% endmacro %}
