{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ru",
  "action.edit": "Редактировать страницу",
  "action.skip": "Перейти к содержанию",
  "clipboard.copy": "Копировать в буфер",
  "clipboard.copied": "Скопировано в буфер",
  "footer": "Нижний колонтитул",
  "footer.next": "Вперед",
  "footer.previous": "Назад",
  "header": "Верхний колонтитул",
  "meta.comments": "Комментарии",
  "meta.source": "Исходный код",
  "nav": "Навигация",
  "search": "Поиск",
  "search.config.lang": "ru",
  "search.placeholder": "Поиск",
  "search.share": "Поделиться",
  "search.reset": "Очистить",
  "search.result.initializer": "Инициализация поиска",
  "search.result.placeholder": "Начните печатать для поиска",
  "search.result.none": "Совпадений не найдено",
  "search.result.one": "Найдено 1 совпадение",
  "search.result.other": "Найдено совпадений: #",
  "search.result.more.one": "Ещё 1 на этой странице",
  "search.result.more.other": "Ещё # на этой странице",
  "search.result.term.missing": "Отсутствует",
  "select.language": "Выберите язык",
  "select.version": "Выберите версию",
  "source": "Перейти к репозиторию",
  "source.file.date.created": "Дата создания",
  "source.file.date.updated": "Последнее обновление",
  "tabs": "Вкладки",
  "toc": "Содержание раздела",
  "top": "К началу"
}[key] }}{% endmacro %}
