{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "sk",
  "action.edit": "Upraviť túto stránku",
  "action.skip": "Preskočiť na obsah",
  "clipboard.copy": "Kopírovať do schránky",
  "clipboard.copied": "Skopírované do schránky",
  "footer.next": "Ďalej",
  "footer.previous": "Späť",
  "meta.comments": "Komentáre",
  "meta.source": "Zdroj",
  "search.placeholder": "Hľadať",
  "search.result.placeholder": "Pre vyhľadávanie začni písať",
  "search.result.none": "Žiadne vyhovujúce dokumenty",
  "search.result.one": "Vyhovujúci dokument: 1",
  "search.result.other": "Vyhovujúce dokumenty: #",
  "source": "Zobraziť repozitár",
  "source.file.date.created": "Vytvorené",
  "source.file.date.updated": "Posledná aktualizácia",
  "toc": "Obsah"
}[key] }}{% endmacro %}
