{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "fi",
  "action.edit": "Muokkaa tätä sivua",
  "action.skip": "Hyppää sisältöön",
  "clipboard.copy": "Kopioi leikepöydälle",
  "clipboard.copied": "Kopioitu leikepöydälle",
  "footer.next": "Seuraava",
  "footer.previous": "Edellinen",
  "meta.comments": "Kommentit",
  "meta.source": "Lähdekodi",
  "search.config.lang": "fi",
  "search.placeholder": "Hae",
  "search.result.placeholder": "Kirjoita aloittaaksesi haun",
  "search.result.none": "Ei täsmääviä dokumentteja",
  "search.result.one": "1 täsmäävä dokumentti",
  "search.result.other": "# täsmäävää dokumenttia",
  "source": "Mene repositoryyn",
  "source.file.date.created": "Luotu",
  "source.file.date.updated": "Viimeisin päivitys",
  "toc": "Sisällysluettelo"
}[key] }}{% endmacro %}
