{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "he",
  "direction": "rtl",
  "action.edit": "עריכת הדף הזה",
  "action.skip": "לדלג לתוכן",
  "announce.dismiss": "לא להציג את זה שוב",
  "clipboard.copy": "העתקה ללוח",
  "clipboard.copied": "הועתק ללוח",
  "consent.accept": "לקבל",
  "consent.manage": "לנהל הגדרות",
  "consent.reject": "לדחות",
  "footer": "כותרת תחתונה",
  "footer.next": "הבא",
  "footer.previous": "הקודם",
  "header": "כותרת עליונה",
  "meta.comments": "הערות",
  "meta.source": "מקור",
  "nav": "ניווט",
  "search": "חיפוש",
  "search.config.pipeline": " ",
  "search.placeholder": "חיפוש",
  "search.share": "שיתוף",
  "search.reset": "ניקוי",
  "search.result.initializer": "אתחול חיפוש",
  "search.result.placeholder": "יש להקליד כדי להתחיל לחפש",
  "search.result.none": "אין מסמכים תואמים",
  "search.result.one": "1 מסמך תואם",
  "search.result.other": "# מסמך תואם",
  "search.result.more.one": "עוד אחד בדף הזה",
  "search.result.more.other": "עוד # בדף הזה",
  "search.result.term.missing": "חסר",
  "select.language": "בחירת שפה",
  "select.version": "בחירת גרסה",
  "source": "לעבור אל המאגר",
  "source.file.date.created": "נוצר",
  "source.file.date.updated": "עדכון אחרון",
  "tabs": "לשוניות",
  "toc": "תוכן העניינים",
  "top": "חזרה למעלה"
}[key] }}{% endmacro %}
