{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "hy",
  "action.edit": "Խմբագրել այս էջը",
  "action.skip": "Անցնել պարունակությանը",
  "clipboard.copy": "Պատճենել",
  "clipboard.copied": "Պատճենված է",
  "footer": "Վերջնագիր",
  "footer.next": "Հաջորդը",
  "footer.previous": "Նախորդը",
  "header": "Գլխագիր",
  "meta.comments": "Մեկնաբանությունները",
  "meta.source": "Աղբյուր",
  "nav": "Տեղորոշում",
  "search": "Փնտրում",
  "search.config.pipeline": " ",
  "search.placeholder": "Փնտրել",
  "search.share": "Կիսվել",
  "search.reset": "Ջնջել",
  "search.result.initializer": "Փնտրում",
  "search.result.placeholder": "Մուտքագրեք փնտրելու համար",
  "search.result.none": "Համապատասխանություններ չկան",
  "search.result.one": "1 համապատասխանություն",
  "search.result.other": "# համապատասխանություններ",
  "search.result.more.one": "ևս 1-ը այս էջում",
  "search.result.more.other": "ևս #-ը այս էջում",
  "search.result.term.missing": "Բացակայում է",
  "select.language": "Ընտրել լեզուն",
  "select.version": "Ընտրել տարբերակը",
  "source": "Դեպի պահոց",
  "source.file.date.created": "Ստեղծված է",
  "source.file.date.updated": "Վերջին թարմացումը",
  "tabs": "Ներդիրներ",
  "toc": "Բովանդակություն",
  "top": "Վերադառնալ սկիզբ"
}[key] }}{% endmacro %}
