{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "fa",
  "direction": "rtl",
  "action.edit": "این صفحه را ویرایش کنید",
  "action.skip": "پرش به محتویات",
  "clipboard.copy": "کپی کردن",
  "clipboard.copied": "کپی شد",
  "footer.next": "بعدی",
  "footer.previous": "قبلی",
  "meta.comments": "نظرات",
  "meta.source": "منبع",
  "search.config.pipeline": " ",
  "search.placeholder": "جستجو",
  "search.result.placeholder": "برای شروع جستجو تایپ کنید",
  "search.result.none": "سندی یافت نشد",
  "search.result.one": "1 سند یافت شد",
  "search.result.other": "# سند یافت شد",
  "source": "رفتن به مخزن",
  "source.file.date.created": "ایجاد شده",
  "source.file.date.updated": "اخرین بروزرسانی",
  "toc": "فهرست موضوعات"
}[key] }}{% endmacro %}
