{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ja",
  "action.edit": "編集",
  "action.skip": "コンテンツにスキップ",
  "clipboard.copy": "クリップボードへコピー",
  "clipboard.copied": "コピーしました",
  "footer": "フッター",
  "footer.next": "次",
  "footer.previous": "前",
  "header": "ヘッダー",
  "meta.comments": "コメント",
  "meta.source": "ソース",
  "nav": "ナビゲーション",
  "search.config.lang": "ja",
  "search.config.pipeline": "stemmer",
  "search.config.separator": "[\\s\\-　、。，．]+",
  "search.placeholder": "検索",
  "search.reset": "クリア",
  "search.result.initializer": "検索を初期化",
  "search.result.placeholder": "検索キーワードを入力してください",
  "search.result.none": "何も見つかりませんでした",
  "search.result.one": "1件見つかりました",
  "search.result.other": "#件見つかりました",
  "search.result.more.one": "このページ内にもう1件見つかりました",
  "search.result.more.other": "このページ内にあと#件見つかりました",
  "search.result.term.missing": "検索に含まれない",
  "source": "リポジトリへ",
  "source.file.date.created": "作成した",
  "source.file.date.updated": "最終更新日",
  "tabs": "タブ",
  "toc": "目次"
}[key] }}{% endmacro %}
