{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "zh-Hant",
  "action.edit": "編輯此頁",
  "action.skip": "跳轉至",
  "clipboard.copy": "拷貝",
  "clipboard.copied": "已拷貝",
  "footer.next": "下一頁",
  "footer.previous": "上一頁",
  "meta.comments": "評論",
  "meta.source": "來源",
  "search.config.lang": "ja",
  "search.config.pipeline": "stemmer",
  "search.config.separator": "[\\s\\-，。]+",
  "search.placeholder": "搜尋",
  "search.result.initializer": "正在初始化搜尋引擎",
  "search.result.placeholder": "鍵入以開始檢索",
  "search.result.none": "沒有找到符合條件的結果",
  "search.result.one": "找到 1 个符合條件的結果",
  "search.result.other": "# 個符合條件的結果",
  "source": "前往倉庫",
  "source.file.date.created": "建立日期",
  "source.file.date.updated": "最後更新",
  "toc": "目錄"
}[key] }}{% endmacro %}
