{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "th",
  "action.edit": "แก้ไขหน้านี้",
  "action.skip": "ข้ามไปที่เนื้อหา",
  "clipboard.copy": "คัดลอก",
  "clipboard.copied": "คัดลอกแล้ว",
  "footer.next": "ต่อไป",
  "footer.previous": "ก่อนหน้า",
  "meta.comments": "ความคิดเห็น",
  "meta.source": "แหล่งที่มา",
  "search.config.lang": "th",
  "search.placeholder": "ค้นหา",
  "search.result.placeholder": "พิมพ์เพื่อเริ่มค้นหา",
  "search.result.none": "ไม่พบเอกสารที่ตรงกัน",
  "search.result.one": "พบเอกสารที่ตรงกัน",
  "search.result.other": "พบ # เอกสารที่ตรงกัน",
  "source": "ไปที่ Repository",
  "source.file.date.created": "สร้าง",
  "source.file.date.updated": "สร้าง",
  "toc": "สารบัญ"
}[key] }}{% endmacro %}
