{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "sv",
  "action.edit": "Redigera sidan",
  "action.skip": "Gå till innehållet",
  "clipboard.copy": "Kopiera till urklipp",
  "clipboard.copied": "Kopierat till urklipp",
  "consent.accept": "Acceptera",
  "consent.manage": "Hantera inställningar",
  "footer": "Sidfot",
  "footer.next": "Nästa",
  "footer.previous": "Föregående",
  "header": "Sidhuvud",
  "meta.comments": "Kommentarer",
  "meta.source": "Källa",
  "nav": "Navigation",
  "search": "Sök",
  "search.config.lang": "sv",
  "search.placeholder": "Sök",
  "search.share": "Dela",
  "search.reset": "Rensa",
  "search.result.initializer": "Initialiserar sök",
  "search.result.placeholder": "Skriv sökord",
  "search.result.none": "Inga sökresultat",
  "search.result.one": "1 sökresultat",
  "search.result.other": "# sökresultat",
  "search.result.more.one": "1 till på denna sidan",
  "search.result.more.other": "# till på denna sidan",
  "search.result.term.missing": "Saknas",
  "select.language": "Välj språk",
  "select.version": "Välj version",
  "source": "Gå till datakatalog",
  "source.file.date.created": "Skapad",
  "source.file.date.updated": "Senaste uppdaterad",
  "tabs": "Flikar",
  "toc": "Innehållsförteckning",
  "top": "Tillbaka till toppen"
}[key] }}{% endmacro %}
