{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "is",
  "action.edit": "Ritvinna þessa síðu",
  "action.skip": "Hoppa yfir í efni",
  "clipboard.copy": "Afrita í klemmuspjald",
  "clipboard.copied": "Afritað í klemmuspjald",
  "footer": "Síðufótur",
  "footer.next": "Næsta",
  "footer.previous": "Fyrra",
  "header": "Haus",
  "meta.comments": "Athugasemdir",
  "meta.source": "Grunnur",
  "nav": "Valmynd",
  "search.placeholder": "Leit",
  "search.reset": "Hreinsa",
  "search.result.placeholder": "Sláðu inn til að hefja leit",
  "search.result.none": "Engin skjöl fundust",
  "search.result.one": "1 skjal fannst",
  "search.result.other": "# skjöl fundust",
  "search.result.more.one": "1 til viðbótar á þessari síðu",
  "search.result.more.other": "# til viðbótar á þessari síðu",
  "source": "Fara í gagnahirslu (e. repository)",
  "source.file.date.created": "Búið til",
  "source.file.date.updated": "Síðasta uppfærsla",
  "tabs": "Flipar",
  "toc": "Efnisyfirlit"
}[key] }}{% endmacro %}
