{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "uk",
  "action.edit": "Редагувати сторінку",
  "action.skip": "Перейти до змісту",
  "clipboard.copy": "Скопіювати в буфер",
  "clipboard.copied": "Скопійовано в буфер",
  "footer.next": "Вперед",
  "footer.previous": "Назад",
  "meta.comments": "Коментарі",
  "meta.source": "Вихідний код",
  "search.config.lang": "ru",
  "search.placeholder": "Пошук",
  "search.result.placeholder": "Розпочніть писати для пошуку",
  "search.result.none": "Збігів не знайдено",
  "search.result.one": "Знайдено 1 збіг",
  "search.result.other": "Знайдено # збігів",
  "source": "Перейти до репозиторію",
  "source.file.date.created": "Створено",
  "source.file.date.updated": "Останнє оновлення",
  "toc": "Зміст"
}[key] }}{% endmacro %}
