{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "eo",
  "action.edit": "Redakti ĉi tiun paĝon",
  "action.skip": "Saltu al enhavo",
  "clipboard.copy": "Kopii al tondujo",
  "clipboard.copied": "Kopiado al klipo",
  "footer": "Piedlinio",
  "footer.next": "Sekva",
  "footer.previous": "Antaŭa",
  "header": "Kaplinio",
  "meta.comments": "Komentoj",
  "meta.source": "Fontkodo",
  "nav": "Navigado",
  "search.config.lang": "es",
  "search.placeholder": "Serĉo",
  "search.reset": "Klara",
  "search.result.placeholder": "Tajpu por komenci serĉadon",
  "search.result.none": "Neniuj kongruaj dokumentoj",
  "search.result.one": "1 kongrua dokumento",
  "search.result.other": "# kongruaj dokumentoj",
  "source": "Iru al deponejo",
  "source.file.date.created": "Kreita",
  "source.file.date.updated": "Lasta ĝisdatigo",
  "tabs": "Langetoj",
  "toc": "Enhavtabelo"
}[key] }}{% endmacro %}
