{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ms",
  "action.edit": "Edit halaman ini",
  "action.skip": "Langkau tajuk talian",
  "clipboard.copy": "Salin ke papan keratan",
  "clipboard.copied": "Disalin ke papan keratan",
  "footer": "Pengaki",
  "footer.next" : "Seterusnya",
  "footer.previous": "Sebelumnya",
  "header": "Pengepala",
  "meta.comments": "Komen",
  "meta.source": "Sumber",
  "nav": "Navigasi",
  "search.placeholder": "Cari",
  "search.reset": "Padam",
  "search.result.initializer": "Siap carian",
  "search.result.placeholder": "Taip untuk mula mencari",
  "search.result.none": "Tiada dokumen yang sepadan",
  "search.result.one": "1 dokumen yang sepadan",
  "search.result.other": "# dokumen yang sepadan",
  "search.result.more.one": "1 lagi di halaman ini",
  "search.result.more.other": "# lagi di halaman ini",
  "search.result.term.missing": "Hilang",
  "select.language": "Pilih bahasa",
  "select.version": "Pilih versi",
  "source": "tajuk talian asal",
  "source.file.date.created": "tarikh fil asal dicipta",
  "source.file.date.updated": "Tarikh fil dikemas kini",
  "tabs": "Tab",
  "toc": "Jadual kandungan",
  "top": "Kembali ke atas"
}[key] }}{% endmacro %}
