{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "hi",
  "action.edit": "इस पृष्ठ को संपादित करें",
  "action.skip": "विषय पर बढ़ें",
  "clipboard.copy": "क्लिपबोर्ड पर कॉपी करें",
  "clipboard.copied": "क्लिपबोर्ड पर कॉपी कर दिया गया",
  "footer.next": "आगामी",
  "footer.previous": "पिछला",
  "meta.comments": "टिप्पणियाँ",
  "meta.source": "स्रोत",
  "search.config.lang": "hi",
  "search.placeholder": "खोज",
  "search.result.placeholder": "खोज शुरू करने के लिए टाइप करें",
  "search.result.none": "कोई मिलान डॉक्यूमेंट नहीं",
  "search.result.one": "1 मिलान डॉक्यूमेंट",
  "search.result.other": "# मिलान डाक्यूमेंट्स",
  "source": "रिपॉजिटरी पर जाएं",
  "source.file.date.created": "बनाया था",
  "source.file.date.updated": "आखिरी अपडेट",
  "toc": "विषय - सूची"
}[key] }}{% endmacro %}
