{#-
  This file was automatically generated - do not edit
-#}
<footer class="md-footer">
  {% if "navigation.footer" in features %}
    <div class="md-footer-nav">
      <nav class="md-footer-nav__inner md-grid" aria-label="{{ lang.t('footer.title') }}">
          <a href="{{ page.previous_page.url | url }}" class="md-footer-nav__link md-footer-nav__link--prev" rel="prev">
            <div class="md-footer-nav__button md-icon">
              {% include ".icons/material/arrow-left.svg" %}
            </div>
            <div class="md-footer-nav__title">
              <div class="md-ellipsis">
                <span class="md-footer-nav__direction">
                  {{ lang.t("footer.previous") }}
                </span>
                {{ page.previous_page.title }}
              </div>
            </div>
          </a>
          <a href="{{ page.next_page.url | url }}" class="md-footer-nav__link md-footer-nav__link--next" rel="next">
            <div class="md-footer-nav__title">
              <div class="md-ellipsis">
                <span class="md-footer-nav__direction">
                  {{ lang.t("footer.next") }}
                </span>
                {{ page.next_page.title }}
              </div>
            </div>
            <div class="md-footer-nav__button md-icon">
              {% include ".icons/material/arrow-right.svg" %}
            </div>
          </a>
      </nav>
    </div>
  {% endif %}
  <div class="md-footer-meta md-typeset">
    <div class="md-footer-meta__inner md-grid">
      {% include "partials/copyright.html" %}
      {% if config.extra.social %}
        {% include "partials/social.html" %}
      {% endif %}
    </div>
  </div>
</footer>
