{#-
  This file was automatically generated - do not edit
-#}
{% if "material/tags" in config.plugins %}
  {% include "partials/tags.html" %}
{% endif %}
{% include "partials/actions.html" %}
{% set first = page.toc | first %}
{% if first and first.level != 1 %}
  <h1>{{ page.title | d(config.site_name, true)}}</h1>
{% endif %}
{{ page.content }}
{% if page.meta and (
  page.meta.git_revision_date_localized or
  page.meta.revision_date
) %}
  {% include "partials/source-file.html" %}
{% endif %}
{% include "partials/feedback.html" %}
{% include "partials/comments.html" %}
