{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "si",
  "action.edit": "පිටුව සංස්කරණය",
  "action.skip": "අන්තර්ගතය වෙත යන්න",
  "clipboard.copy": "කොපි කරන්න",
  "clipboard.copied": "කොපි කළා",
  "footer": "පාදම",
  "footer.next": "මීළඟ",
  "footer.previous": "පසුගිය",
  "header": "ශීර්ෂය",
  "meta.comments": "ප්‍රතිචාර",
  "meta.source": "මූලාශ්‍රය",
  "nav": "යාත්‍රණය",
  "search.config.pipeline": " ",
  "search.placeholder": "සොයන්න",
  "search.reset": "මකන්න",
  "search.result.placeholder": "සෙවීමට ටයිප් කරන්න",
  "search.result.none": "කිසිවක් හමු නොවුණි",
  "search.result.one": "1 ගැලපෙන ගොනුවක්",
  "search.result.other": "ගැලපෙන ගොනු # ක්",
  "search.result.more.one": "තව 1 ප්‍රතිඵලයක්",
  "search.result.more.other": "තව ප්‍රතිඵල # ක්",
  "source": "රිපොසිටරියට යන්න",
  "source.file.date.created": "ٺاھيو ويو",
  "source.file.date.updated": "අවසන් යාවත්කාලීන වීම",
  "tabs": "ටැබ්ස්",
  "toc": "පටුන"
}[key] }}{% endmacro %}
