{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "vi",
  "action.edit": "Chỉnh sửa",
  "action.skip": "Vào thẳng nội dung",
  "clipboard.copy": "Sao chép vào bộ nhớ",
  "clipboard.copied": "Sao chép xong",
  "footer.next": "Sau",
  "footer.previous": "Trước",
  "meta.comments": "Bình luận",
  "meta.source": "Mã nguồn",
  "search.config.lang": "vi",
  "search.placeholder": "Tìm kiếm",
  "search.result.placeholder": "Nhập để bắt đầu tìm kiếm",
  "search.result.none": "Không tìm thấy tài liệu liên quan",
  "search.result.one": "1 tài liệu liên quan",
  "search.result.other": "# tài liệu liên quan",
  "source": "Đến kho lưu trữ mã nguồn",
  "source.file.date.created": "Tạo",
  "source.file.date.updated": "Cập nhật cuối cùng",
  "toc": "Mục lục"
}[key] }}{% endmacro %}
