{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "pt",
  "action.edit": "Editar esta página",
  "action.skip": "Pular para conteúdo",
  "clipboard.copy": "Copiar para área de Transferência",
  "clipboard.copied": "Copiado para área de Transferência",
  "footer": "Rodapé",
  "footer.next": "Próximo",
  "footer.previous": "Anterior",
  "header": "Cabeçalho",
  "meta.comments": "Comentários",
  "meta.source": "Origem",
  "nav": "Navegação",
  "search.config.lang": "pt",
  "search.placeholder": "Buscar",
  "search": "Pesquisar",
  "search.reset": "Limpar",
  "search.result.initializer": "Inicializando busca",
  "search.result.placeholder": "Digite para iniciar a busca",
  "search.result.none": "Nenhum documento encontrado",
  "search.result.one": "1 documento encontrado",
  "search.result.other": "# documentos encontrados",
  "search.result.more.one": "1 more on this page",
  "search.result.more.other": "# more on this page",
  "search.result.term.missing": "Perdido",
  "select.language": "Selecione a linguagem",
  "select.version": "Selecione a versão",
  "source": "Ir para repositório",
  "source.file.date.created": "Criado em",
  "source.file.date.updated": "Ultima atualização",
  "tabs": "Abas",
  "toc": "Indice",
  "top": "Voltar para o topo"
}[key] }}{% endmacro %}
