{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "da",
  "action.edit": "Redigér denne side",
  "action.skip": "Gå til indholdet",
  "clipboard.copy": "Kopiér til udklipsholderen",
  "clipboard.copied": "Kopieret til udklipsholderen",
  "footer.next": "Næste",
  "footer.previous": "Forrige",
  "meta.comments": "Kommentarer",
  "meta.source": "Kilde",
  "search.config.lang": "da",
  "search.placeholder": "Søg",
  "search.result.placeholder": "Indtast søgeord",
  "search.result.none": "Ingen resultater fundet",
  "search.result.one": "1 resultat",
  "search.result.other": "# resultater",
  "source": "Åbn arkiv",
  "source.file.date.created": "Oprettet",
  "source.file.date.updated": "Sidste ændring",
  "toc": "Indholdsfortegnelse"
}[key] }}{% endmacro %}
