{#-
  This file was automatically generated - do not edit
-#}
<div class="md-social">
  {% for social in config.extra.social %}
    {% set title = social.name %}
    {% if not title and "//" in social.link %}
      {% set _, url = social.link.split("//") %}
      {% set title  = url.split("/")[0] %}
    {% endif %}
    <a href="{{ social.link }}" target="_blank" rel="noopener" title="{{ title | e }}" class="md-social__link">
      {% include ".icons/" ~ social.icon ~ ".svg" %}
    </a>
  {% endfor %}
</div>
