{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "hu",
  "action.edit": "Oldal szerkesztése",
  "action.skip": "Kihagyás",
  "clipboard.copy": "Másolás vágólapra",
  "clipboard.copied": "Vágólapra másolva",
  "footer": "Élőláb",
  "footer.next": "Következő",
  "footer.previous": "Előző",
  "header": "Élőfej",
  "meta.comments": "Hozzászólások",
  "meta.source": "Forrás",
  "nav": "Navigáció",
  "search.config.lang": "hu",
  "search.placeholder": "Keresés",
  "search.reset": "Törlés",
  "search.result.initializer": "Keresés inicializálása",
  "search.result.placeholder": "Kereséshez írj ide valamit",
  "search.result.none": "Nincs találat",
  "search.result.one": "1 egyező dokumentum",
  "search.result.other": "# egyező dokumentum",
  "search.result.more.one": "1 további találat az oldalon",
  "search.result.more.other": "# további találat az oldalon",
  "search.result.term.missing": "Üres",
  "source": "Főoldalra ugrás",
  "source.file.date.created": "Létrehozva",
  "source.file.date.updated": "Utolsó frissítés",
  "tabs": "Lapok",
  "toc": "Tartalomjegyzék"
}[key] }}{% endmacro %}
