{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "de",
  "action.edit": "Seite editieren",
  "action.skip": "Zum Inhalt",
  "action.view": "Quellcode der Seite anzeigen",
  "announce.dismiss": "Nicht mehr anzeigen",
  "clipboard.copy": "In Zwischenablage kopieren",
  "clipboard.copied": "In Zwischenablage kopiert",
  "consent.accept": "Akzeptieren",
  "consent.manage": "Einstellungen",
  "consent.reject": "Ablehnen",
  "footer": "Fußzeile",
  "footer.next": "Weiter",
  "footer.previous": "Zurück",
  "header": "Kopfzeile",
  "meta.comments": "Kommentare",
  "meta.source": "Quellcode",
  "nav": "Navigation",
  "search": "Suche",
  "search.config.lang": "de",
  "search.placeholder": "Suche",
  "search.share": "Teilen",
  "search.reset": "Zurücksetzen",
  "search.result.initializer": "Suche wird initialisiert",
  "search.result.placeholder": "Suchbegriff eingeben",
  "search.result.none": "Keine Suchergebnisse",
  "search.result.one": "1 Suchergebnis",
  "search.result.other": "# Suchergebnisse",
  "search.result.more.one": "1 weiteres Suchergebnis auf dieser Seite",
  "search.result.more.other": "# weitere Suchergebnisse auf dieser Seite",
  "search.result.term.missing": "Es fehlt",
  "select.language": "Sprache wechseln",
  "select.version": "Version auswählen",
  "source": "Zum Repository",
  "source.file.date.created": "Erstellt",
  "source.file.date.updated": "Letztes Update",
  "tabs": "Hauptnavigation",
  "toc": "Inhaltsverzeichnis",
  "top": "Zurück zum Seitenanfang"
}[key] }}{% endmacro %}
