{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "tl",
  "action.edit": "I-edit ang pahinang ito",
  "action.skip": "I-skip tungo sa nilalaman",
  "clipboard.copy": "Kopyahin sa clipboard",
  "clipboard.copied": "Nakopya mula sa clipboard",
  "footer": "Lagdang Pangwakas",
  "footer.next": "Susunod",
  "footer.previous": "Nakaraan",
  "header": "Pamuhatan",
  "meta.comments": "Mga Komento",
  "meta.source": "Pinagmulan",
  "nav": "Nabigasyon",
  "search": "Hanapin",
  "search.placeholder": "Hanapin",
  "search.share": "Ibahagi",
  "search.reset": "Tanggalin",
  "search.result.initializer": "Sinisimulan ang paghahanap",
  "search.result.placeholder": "Mag-type upang simulan ang paghahanap",
  "search.result.none": "Walang nahanap na dokumento",
  "search.result.one": "1 magkatugmang dokumento",
  "search.result.other": "# magkatugmang mga dokumento",
  "search.result.more.one": "1 meron sa pahina na ito",
  "search.result.more.other": "# meron sa pahina na ito",
  "search.result.term.missing": "Nawawala",
  "select.language": "Pumili ng lenguwahe",
  "select.version": "Pumili ng bersyon",
  "source": "Pumunta sa repository",
  "source.file.date.created": "Nagawa",
  "source.file.date.updated": "Huling update",
  "tabs": "Mga tala",
  "toc": "Talaan ng nilalaman",
  "top": "Bumalik sa taas"
}[key] }}{% endmacro %}
