{#-
  This file was automatically generated - do not edit
-#}
<hr>
<div class="md-source-file">
  <small>
    {% if page.meta.git_revision_date_localized %}
      {{ lang.t("source.file.date.updated") }}:
      {{ page.meta.git_revision_date_localized }}
      {% if page.meta.git_creation_date_localized %}
        <br>
        {{ lang.t("source.file.date.created") }}:
        {{ page.meta.git_creation_date_localized }}
      {% endif %}
    {% elif page.meta.revision_date %}
      {{ lang.t("source.file.date.updated") }}:
      {{ page.meta.revision_date }}
    {% endif %}
  </small>
</div>
