{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "fr",
  "action.edit": "Editer cette page",
  "action.skip": "Aller au contenu",
  "clipboard.copy": "Copier dans le presse-papier",
  "clipboard.copied": "Copié dans le presse-papier",
  "consent.accept": "Accepter",
  "consent.manage": "Paramétrer vos choix",
  "consent.reject": "Refuser",
  "footer": "Pied de page",
  "footer.next": "Suivant",
  "footer.previous": "Précédent",
  "header": "En-tête",
  "meta.comments": "Commentaires",
  "meta.source": "Source",
  "nav": "Navigation",
  "search.config.lang": "fr",
  "search.placeholder": "Rechercher",
  "search.reset": "Effacer",
  "search.result.initializer": "Initialisation de la recherche",
  "search.result.placeholder": "Taper pour démarrer la recherche",
  "search.result.none": "Aucun document trouvé",
  "search.result.one": "1 document trouvé",
  "search.result.other": "# documents trouvés",
  "search.result.more.one": "1 de plus sur cette page",
  "search.result.more.other": "# de plus sur cette page",
  "search.result.term.missing": "Non trouvé",
  "select.language": "Sélectionner la langue",
  "select.version": "Sélectionner la version",
  "source": "Aller au dépôt",
  "source.file.date.created": "Créé",
  "source.file.date.updated": "Dernière mise à jour",
  "tabs": "Onglets",
  "toc": "Table des matières",
  "top": "Retour en haut de la page"
}[key] }}{% endmacro %}
